#region Copyright Syncfusion Inc. 2001 - 2006
//
//  Copyright Syncfusion Inc. 2001 - 2006. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Runtime.Serialization;
using System.Windows.Forms;
using System.IO;
using System.Collections.Generic;

using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Styles;


namespace TwoTextBoxCell
{
	#region Cellmodel
	public class TwoTextBoxCellModel : GridGenericControlCellModel
	{
		public TwoTextBoxCellModel(GridModel grid)
			: base(grid)
		{
			
		}
	
		protected TwoTextBoxCellModel(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
		}

		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new TwoTextBoxCellRenderer(control, this);
		}

		protected override Size OnQueryPrefferedClientSize(Graphics g, int rowIndex, int colIndex, GridStyleInfo style, GridQueryBounds queryBounds)
		{
			Size s = base.OnQueryPrefferedClientSize(g, rowIndex, colIndex, style, queryBounds);
			return new Size(s.Width + 175 , 50 );
		}

		public static void InitializeTwoTextBox(TwoTextCell c, GridStyleInfo style)
		{
			c.TopValue = string.Empty; 
			c.BottomValue = string.Empty; 
			if( style.CellValue != null )
			{
                IList<Customer> customerList = style.CellValue as List<Customer>;
                if (customerList != null && customerList.Count > 0)
                {
                    c.TopValue = customerList[0].CustomerID;
                    c.BottomValue = customerList[0].CustomerName;
                    c.BackColor = style.BackColor;
                    c.textBox1.BackColor = style.BackColor;
                    c.textBox2.BackColor = style.BackColor;
                }
			}
			
		}
	}
	
	#endregion

	#region CellRenderer
	public class TwoTextBoxCellRenderer: GridGenericControlCellRenderer
	{
		TwoTextCell drawTwoTextCell = new TwoTextCell();
		TwoTextCell editTwoTextCell = new TwoTextCell();
		TwoTextBoxCellModel cm;
		
		Hashtable CellModifiy = new Hashtable();

		public TwoTextBoxCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{
			cm = (TwoTextBoxCellModel) cellModel;
			SupportsFocusControl = true;
			SupportsEditing = true;
			FixControlParent(drawTwoTextCell);
			SetControl(editTwoTextCell);
			editTwoTextCell.textBox1.TextChanged +=new EventHandler(TextChanged);
			editTwoTextCell.textBox2.TextChanged +=new EventHandler(TextChanged);
		}

		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				drawTwoTextCell.Dispose();
				drawTwoTextCell = null;

				editTwoTextCell.Dispose();
				editTwoTextCell = null;

				cm = null;
			}

			base.Dispose (disposing);
		}

		protected override void OnInitialize(int rowIndex, int colIndex)
		{
			TwoTextBoxCellModel.InitializeTwoTextBox(editTwoTextCell, Grid.GetViewStyleInfo(rowIndex, colIndex));
			
		}

		protected override void OnDraw(Graphics g, Rectangle clientRectangle, int rowIndex, int colIndex, GridStyleInfo style)
		{
			if (this.ShouldDrawFocused(rowIndex,colIndex))
			{
				style.Control = editTwoTextCell;
			}
			else
			{
				style.Control = drawTwoTextCell;
				TwoTextBoxCellModel.InitializeTwoTextBox(drawTwoTextCell, style);
			}
			base.OnDraw (g, clientRectangle, rowIndex, colIndex, style);
		}
		protected /*internal*/ override bool OnSaveChanges()
		{
			GridTableControl tc = this.Grid as GridTableControl;
			GridTableCellStyleInfo info = this.Grid.Model[ RowIndex, ColIndex ] as GridTableCellStyleInfo; 
			if( tc != null && info.TableCellIdentity.DisplayElement.Kind == Syncfusion.Grouping.DisplayElementKind.AddNewRecord)
			{
				tc.Table.AddNew();
			}
            IList<Customer> customerList = new List<Customer>();
            customerList.Add(new Customer(editTwoTextCell.TopValue, editTwoTextCell.BottomValue));

            this.Grid.Model[RowIndex, ColIndex].CellValue = customerList;
            CurrentCell.IsModified = false;
			return true;
		}
		private object GetHashCode(int row,int col)
		{
			return "#" + row +"##" +col;
		}
		
		protected override Rectangle OnLayout(int rowIndex, int colIndex, GridStyleInfo style, Rectangle innerBounds, Rectangle[] buttonsBounds)
		{
			Rectangle r = base.OnLayout (rowIndex, colIndex, style, innerBounds, buttonsBounds);

			r.Inflate(-1, -1);

			return r;
		}
		protected override void OnClick(int rowIndex, int colIndex, MouseEventArgs e)
		{
			base.OnClick (rowIndex, colIndex, e);
			
		}

		private void TextChanged(object sender, EventArgs e)
		{
			CurrentCell.IsModified = true;
		}
	}

	#endregion 

	
}
